@@ -1,11 +1,12 @@
 """
 Grok error because import model doesn't count as context:
 
-  >>> grok.grok(__name__)
+  >>> grok.testing.grok(__name__)
   Traceback (most recent call last):
     ...
   GrokError: No module-level context for
-  <class 'grok.tests.adapter.importedmodel2.Painting'>, please use grok.context.
+  <class 'grok.tests.adapter.importedmodel2.Painting'>,
+  please use the 'context' directive.
 
 """
 import grok
